Note that all files in this directory stem from the 4_cam_A session, recording 4.

Note that "base" data refers to the fact that it is not gap-filled and not smoothed. 

Thinking through the steps that must occur:

xy_base
xy_gapfilled
xy_smoothed
xyz_base
xyz_gapfilled
xyz_smoothed


The SIMPLE_HOLISTIC folder is here ot align with the general structure of a session layout